@@ -3,7 +3,7 @@
 # Initialization script normally executed in the interpreter for each
 # Tk-based application.  Arranges class bindings for widgets.
 #
-# RCS: @(#) $Id: tk.tcl,v 1.44 2002/09/09 23:52:02 hobbs Exp $
+# RCS: @(#) $Id: tk.tcl,v 1.46 2003/02/18 21:24:39 hobbs Exp $
 #
 # Copyright (c) 1992-1994 The Regents of the University of California.
 # Copyright (c) 1994-1996 Sun Microsystems, Inc.
@@ -350,18 +350,12 @@ switch [tk windowingsystem] {
 	# that is returned when the user presses <Shift-Tab>.  In order for
 	# tab traversal to work, we have to add these keysyms to the 
 	# PrevWindow event.
-	# The info exists is necessary, because tcl_platform(os) doesn't
-	# exist in safe interpreters.
-	if {[info exists tcl_platform(os)]} {
-	    switch $tcl_platform(os) {
-		"IRIX"  -
-		"Linux" { event add <<PrevWindow>> <ISO_Left_Tab> }
-		"HP-UX" {
-		    # This seems to be correct on *some* HP systems.
-		    catch { event add <<PrevWindow>> <hpBackTab> }
-		}
-	    }
-	}
+	# We use catch just in case the keysym isn't recognized.
+	# This is needed for XFree86 systems
+	catch { event add <<PrevWindow>> <ISO_Left_Tab> }
+	# This seems to be correct on *some* HP systems.
+	catch { event add <<PrevWindow>> <hpBackTab> }
+
 	trace variable ::tk_strictMotif w ::tk::EventMotifBindings
 	set ::tk_strictMotif $::tk_strictMotif
     }
@@ -448,13 +442,14 @@ proc ::tk::CancelRepeat {} {
 
 # ::tk::TabToWindow --
 # This procedure moves the focus to the given widget.  If the widget
-# is an entry, it selects the entire contents of the widget.
+# is an entry or a spinbox, it selects the entire contents of the widget.
 #
 # Arguments:
 # w - Window to which focus should be set.
 
 proc ::tk::TabToWindow {w} {
-    if {[string equal [winfo class $w] Entry]} {
+    if {[string equal [winfo class $w] Entry] \
+	    || [string equal [winfo class $w] Spinbox]} {
 	$w selection range 0 end
 	$w icursor end
     }
